@@ -66,8 +66,12 @@ Container for LDAP-related stuff.
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( ldap_exists ldap_auth ldap_search populate_employee );
-
+our @EXPORT_OK = qw(
+    autocreate_employee
+    ldap_exists
+    ldap_auth
+    ldap_search
+);
 
 
 
@@ -187,46 +191,4 @@ sub ldap_auth {
     return 0;
 }
 
-
-=head2 populate_employee
-
-Populate employee profile from LDAP. Takes employee object which must have the
-'nick' property already populated. Returns a status object.
-
-=cut
-
-sub populate_employee {
-    my ( $emp ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::populate_employee()" );
-
-    return $CELL->status_err( "LDAP not enabled" ) unless $site->DOCHAZKA_LDAP;
-    return $CELL->status_err( "nick property not populated" ) unless $emp->nick;
-
-    $log->debug( "About to populate " . $emp->nick . " from LDAP" );
-
-    require Net::LDAP;
-
-    # initiate connection to LDAP server (anonymous bind)
-    my $server = $site->DOCHAZKA_LDAP_SERVER;
-    my $ldap = Net::LDAP->new( $server );
-    $log->error("$@") unless $ldap;
-    return $CELL->status_err( 'Could not connect to LDAP server' ) unless $ldap;
-
-    # get LDAP properties and stuff them into the employee object
-    my $count = 0;
-    foreach my $key ( keys( %{ $site->DOCHAZKA_LDAP_MAPPING } ) ) {
-        my $prop = $site->DOCHAZKA_LDAP_MAPPING->{ $key };
-        my $value = ldap_search( $ldap, $emp->nick, $prop );
-        last unless $value;
-        $log->debug( "Setting $key to $value" );
-        $emp->set( $key, $value );
-        $count += 1;
-    }
-
-    $ldap->unbind;
-
-    return $CELL->status_ok( "$count properties populated from LDAP", payload => $emp ) if $count > 0;
-    return $CELL->status_not_ok;
-}
-
 1;
